==> v20.23.tar.gz: v20.23/socket_ctrl.c <==
#include "config.h"

#ifndef OS2
/*
  ioctl.c: part of the MudOS release -- Truilkan@TMI

  isolates the code which sets the various socket modes since various
  machines seem to need this done in different ways.
*/

#include <stdio.h>
#ifdef SunOS_5
#include <unistd.h>
#endif
#include <sys/types.h>
#if !defined(LATTICE) && !defined(OS2)
#include <sys/ioctl.h>
#include <sys/socket.h>
#endif
#ifdef LATTICE
#include <amiga.h>
#include <socket.h>
#endif
#if defined(_SEQUENT_) || defined(OLD_ULTRIX)
#include <fcntl.h>
#endif
#if defined(SVR4)
#include <fcntl.h>
#include <sys/filio.h>
#include <sys/sockio.h>
#endif
#include "lint.h"

/*
 * set process receiving SIGIO/SIGURG signals to us.
 */

INLINE int set_socket_owner P2(int, fd, int, which)
{
#ifdef OLD_ULTRIX
    return fcntl(fd, F_SETOWN, which);
#else
    return ioctl(fd, SIOCSPGRP, &which);
#endif
}

/*
 * allow receipt of asynchronous I/O signals.
 */

INLINE int set_socket_async P2(int, fd, int, which)
{
#ifdef OLD_ULTRIX
    return fcntl(fd, F_SETFL, FASYNC);
#else
    return ioctl(fd, FIOASYNC, &which);
#endif
}

/*
 * set socket non-blocking
 */

INLINE int set_socket_nonblocking P2(int, fd, int, which)
{
#if !defined(OLD_ULTRIX) && !defined(_SEQUENT_)
    int result;

#endif

#ifdef OLD_ULTRIX
    if (which)
	return fcntl(fd, F_SETFL, FNDELAY);
    else
	return fcntl(fd, F_SETFL, FNBLOCK);
#else

#ifdef _SEQUENT_
    int flags = fcntl(fd, F_GETFL, 0);

    if (flags == -1)
	return (-1);
    if (which)
	flags |= O_NONBLOCK;
    else
	flags &= ~O_NONBLOCK;
    return fcntl(fd, F_SETFL, flags);
#else
    result = ioctl(fd, FIONBIO, &which);
    if (result == -1) {
	fprintf(stderr, "Try using cc instead of gcc to correct this error.\n");
    }
    return result;
#endif

#endif
}

#endif				/* OS2 */

==> v21.4.tar.gz: v21.4/socket_ctrl.c <==
#include "std.h"
#include "network_incl.h"
#include "lpc_incl.h"
#include "file.h"

#ifndef OS2
/*
  ioctl.c: part of the MudOS release -- Truilkan@TMI

  isolates the code which sets the various socket modes since various
  machines seem to need this done in different ways.
*/

#if defined(SVR4)
#include <sys/filio.h>
#include <sys/sockio.h>
#endif

/*
 * set process receiving SIGIO/SIGURG signals to us.
 */

INLINE int set_socket_owner P2(int, fd, int, which)
{
#ifdef OLD_ULTRIX
    return fcntl(fd, F_SETOWN, which);
#else
    return ioctl(fd, SIOCSPGRP, &which);
#endif
}

/*
 * allow receipt of asynchronous I/O signals.
 */

INLINE int set_socket_async P2(int, fd, int, which)
{
#ifdef OLD_ULTRIX
    return fcntl(fd, F_SETFL, FASYNC);
#else
    return ioctl(fd, FIOASYNC, &which);
#endif
}

/*
 * set socket non-blocking
 */

INLINE int set_socket_nonblocking P2(int, fd, int, which)
{
#if !defined(OLD_ULTRIX) && !defined(_SEQUENT_)
    int result;
#endif

#ifdef OLD_ULTRIX
    if (which)
	return fcntl(fd, F_SETFL, FNDELAY);
    else
	return fcntl(fd, F_SETFL, FNBLOCK);
#else

#ifdef _SEQUENT_
    int flags = fcntl(fd, F_GETFL, 0);

    if (flags == -1)
	return (-1);
    if (which)
	flags |= O_NONBLOCK;
    else
	flags &= ~O_NONBLOCK;
    return fcntl(fd, F_SETFL, flags);
#else
    result = ioctl(fd, FIONBIO, &which);
    if (result == -1)
	debug_perror("set_socket_nonblocking: ioctl", 0);
#if 0
    /* boggle ... someone track down an errno for this */
    if (result == -1) {
	XXX("Try using cc instead of gcc to correct this error.\n");
    }
#endif
    return result;
#endif

#endif
}

#endif				/* OS2 */
